==> smack-core-4.1.0-rc2-sources.jar: org/jivesoftware/smack/filter/ThreadFilter.java <==
/**
 *
 * Copyright 2003-2007 Jive Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jivesoftware.smack.filter;

import org.jivesoftware.smack.packet.Message;
import org.jivesoftware.smack.util.StringUtils;

/**
 * Filters for message packets with a particular thread value.
 *
 * @author Matt Tucker
 */
public class ThreadFilter extends FlexiblePacketTypeFilter<Message> implements PacketFilter {

    private final String thread;

    /**
     * Creates a new thread filter using the specified thread value.
     *
     * @param thread the thread value to filter for.
     */
    public ThreadFilter(String thread) {
        StringUtils.requireNotNullOrEmpty(thread, "Thread must not be null or empty.");
        this.thread = thread;
    }

    @Override
    protected boolean acceptSpecific(Message message) {
        return thread.equals(message.getThread());
    }

    @Override
    public String toString() {
        return getClass().getSimpleName() + ": thread=" + thread;
    }
}

==> smack-core-4.3.0-sources.jar: org/jivesoftware/smack/filter/ThreadFilter.java <==
/**
 *
 * Copyright 2003-2007 Jive Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jivesoftware.smack.filter;

import org.jivesoftware.smack.packet.Message;
import org.jivesoftware.smack.util.StringUtils;

/**
 * Filters for message packets with a particular thread value.
 *
 * @author Matt Tucker
 */
public class ThreadFilter extends FlexibleStanzaTypeFilter<Message> implements StanzaFilter {

    private final String thread;

    /**
     * Creates a new thread filter using the specified thread value.
     *
     * @param thread the thread value to filter for.
     */
    public ThreadFilter(String thread) {
        StringUtils.requireNotNullOrEmpty(thread, "Thread must not be null or empty.");
        this.thread = thread;
    }

    @Override
    protected boolean acceptSpecific(Message message) {
        return thread.equals(message.getThread());
    }

    @Override
    public String toString() {
        return getClass().getSimpleName() + ": thread=" + thread;
    }
}
